/*------------------------------------*
	$SOCIAL MENU
*------------------------------------*/
#oceanwp-social-menu {
  float: right;
  display: table;
  position: relative;
  z-index: 10;
}

#oceanwp-social-menu.simple-social {
  right: -8px;
}

#oceanwp-social-menu.social-with-style {
  right: -2px;
}

#oceanwp-social-menu .social-menu-inner {
  display: table-cell;
  vertical-align: middle;
  height: 74px;
}

#oceanwp-social-menu ul {
  margin: 0;
  padding: 0;
  list-style: none;
}

#oceanwp-social-menu ul li {
  float: left;
  position: relative;
}

#oceanwp-social-menu ul li a {
  display: inline-block;
  background-color: transparent;
  color: #929292;
  padding: 0 8px;
  text-align: center;
  letter-spacing: 0;
}

#oceanwp-social-menu ul li a span {
  text-align: center;
}

#oceanwp-social-menu ul li a:hover {
  background-color: transparent;
}

#oceanwp-social-menu ul li.oceanwp-twitter a:hover {
  color: #46d4fe;
}

#oceanwp-social-menu ul li.oceanwp-facebook a:hover {
  color: #37589b;
}

#oceanwp-social-menu ul li.oceanwp-googleplus a:hover {
  color: #de5a49;
}

#oceanwp-social-menu ul li.oceanwp-pinterest a:hover {
  color: #cb2027;
}

#oceanwp-social-menu ul li.oceanwp-dribbble a:hover {
  color: #ea4c89;
}

#oceanwp-social-menu ul li.oceanwp-vk a:hover {
  color: #597BA5;
}

#oceanwp-social-menu ul li.oceanwp-instagram a:hover {
  color: #3F729B;
}

#oceanwp-social-menu ul li.oceanwp-linkedin a:hover {
  color: #3399CC;
}

#oceanwp-social-menu ul li.oceanwp-tumblr a:hover {
  color: #2C4762;
}

#oceanwp-social-menu ul li.oceanwp-github a:hover {
  color: #60b044;
}

#oceanwp-social-menu ul li.oceanwp-flickr a:hover {
  color: #fa4086;
}

#oceanwp-social-menu ul li.oceanwp-skype a:hover {
  color: #00AFF0;
}

#oceanwp-social-menu ul li.oceanwp-youtube a:hover {
  color: #C4302B;
}

#oceanwp-social-menu ul li.oceanwp-vimeo a:hover {
  color: #1ab7ea;
}

#oceanwp-social-menu ul li.oceanwp-vine a:hover {
  color: #00bf8f;
}

#oceanwp-social-menu ul li.oceanwp-xing a:hover {
  color: #006464;
}

#oceanwp-social-menu ul li.oceanwp-yelp a:hover {
  color: #C41200;
}

#oceanwp-social-menu ul li.oceanwp-tripadvisor a:hover {
  color: #589442;
}

#oceanwp-social-menu ul li.oceanwp-rss a:hover {
  color: #ff7900;
}

#oceanwp-social-menu ul li.oceanwp-email a:hover {
  color: #13aff0;
}

#oceanwp-social-menu .colored ul li {
  padding: 0 2px;
}

#oceanwp-social-menu .colored ul li a {
  position: relative;
  display: inline-block;
  font-size: 12px;
  color: #fff;
  line-height: 1;
  padding: 1em;
  border-radius: 50%;
  vertical-align: middle;
  -webkit-transition: all .3s ease-out;
  -moz-transition: all .3s ease-out;
  -o-transition: all .3s ease-out;
  transition: all .3s ease-out;
}

#oceanwp-social-menu .colored ul li a:hover {
  color: #fff;
}

#oceanwp-social-menu .colored ul li a span {
  width: 1em;
  height: 1em;
}

#oceanwp-social-menu .colored ul li.oceanwp-twitter a {
  background-color: #46d4fe;
}

#oceanwp-social-menu .colored ul li.oceanwp-twitter a:hover {
  background-color: #39b4d8;
}

#oceanwp-social-menu .colored ul li.oceanwp-facebook a {
  background-color: #37589b;
}

#oceanwp-social-menu .colored ul li.oceanwp-facebook a:hover {
  background-color: #2d477c;
}

#oceanwp-social-menu .colored ul li.oceanwp-googleplus a {
  background-color: #de5a49;
}

#oceanwp-social-menu .colored ul li.oceanwp-googleplus a:hover {
  background-color: #bb4c3e;
}

#oceanwp-social-menu .colored ul li.oceanwp-pinterest a {
  background-color: #cb2027;
}

#oceanwp-social-menu .colored ul li.oceanwp-pinterest a:hover {
  background-color: #a91d23;
}

#oceanwp-social-menu .colored ul li.oceanwp-dribbble a {
  background-color: #ea4c89;
}

#oceanwp-social-menu .colored ul li.oceanwp-dribbble a:hover {
  background-color: #c64174;
}

#oceanwp-social-menu .colored ul li.oceanwp-vk a {
  background-color: #597BA5;
}

#oceanwp-social-menu .colored ul li.oceanwp-vk a:hover {
  background-color: #486384;
}

#oceanwp-social-menu .colored ul li.oceanwp-instagram a {
  background-color: #3F729B;
}

#oceanwp-social-menu .colored ul li.oceanwp-instagram a:hover {
  background-color: #315a7c;
}

#oceanwp-social-menu .colored ul li.oceanwp-linkedin a {
  background-color: #3399CC;
}

#oceanwp-social-menu .colored ul li.oceanwp-linkedin a:hover {
  background-color: #2678a1;
}

#oceanwp-social-menu .colored ul li.oceanwp-tumblr a {
  background-color: #2C4762;
}

#oceanwp-social-menu .colored ul li.oceanwp-tumblr a:hover {
  background-color: #1d3042;
}

#oceanwp-social-menu .colored ul li.oceanwp-github a {
  background-color: #60b044;
}

#oceanwp-social-menu .colored ul li.oceanwp-github a:hover {
  background-color: #4f9237;
}

#oceanwp-social-menu .colored ul li.oceanwp-flickr a {
  background-color: #fa4086;
}

#oceanwp-social-menu .colored ul li.oceanwp-flickr a:hover {
  background-color: #c63169;
}

#oceanwp-social-menu .colored ul li.oceanwp-skype a {
  background-color: #00AFF0;
}

#oceanwp-social-menu .colored ul li.oceanwp-skype a:hover {
  background-color: #0291c6;
}

#oceanwp-social-menu .colored ul li.oceanwp-youtube a {
  background-color: #C4302B;
}

#oceanwp-social-menu .colored ul li.oceanwp-youtube a:hover {
  background-color: #982420;
}

#oceanwp-social-menu .colored ul li.oceanwp-vimeo a {
  background-color: #1ab7ea;
}

#oceanwp-social-menu .colored ul li.oceanwp-vimeo a:hover {
  background-color: #1494bd;
}

#oceanwp-social-menu .colored ul li.oceanwp-vine a {
  background-color: #00bf8f;
}

#oceanwp-social-menu .colored ul li.oceanwp-vine a:hover {
  background-color: #01906c;
}

#oceanwp-social-menu .colored ul li.oceanwp-xing a {
  background-color: #006464;
}

#oceanwp-social-menu .colored ul li.oceanwp-xing a:hover {
  background-color: #014646;
}

#oceanwp-social-menu .colored ul li.oceanwp-yelp a {
  background-color: #C41200;
}

#oceanwp-social-menu .colored ul li.oceanwp-yelp a:hover {
  background-color: #940f01;
}

#oceanwp-social-menu .colored ul li.oceanwp-tripadvisor a {
  background-color: #589442;
}

#oceanwp-social-menu .colored ul li.oceanwp-tripadvisor a:hover {
  background-color: #426f32;
}

#oceanwp-social-menu .colored ul li.oceanwp-rss a {
  background-color: #ff7900;
}

#oceanwp-social-menu .colored ul li.oceanwp-rss a:hover {
  background-color: #d46603;
}

#oceanwp-social-menu .colored ul li.oceanwp-email a {
  background-color: #13aff0;
}

#oceanwp-social-menu .colored ul li.oceanwp-email a:hover {
  background-color: #0f8dc2;
}

#oceanwp-social-menu .minimal ul li {
  padding: 0 2px;
}

#oceanwp-social-menu .minimal ul li a {
  position: relative;
  display: inline-block;
  font-size: 12px;
  color: #bbb;
  border: 1px solid #ccc;
  line-height: 1;
  padding: 1em;
  border-radius: 50%;
  vertical-align: middle;
  -webkit-transition: all .3s ease-out;
  -moz-transition: all .3s ease-out;
  -o-transition: all .3s ease-out;
  transition: all .3s ease-out;
}

#oceanwp-social-menu .minimal ul li a span {
  width: 1em;
  height: 1em;
}

#oceanwp-social-menu .minimal ul li.oceanwp-twitter a:hover {
  color: #46d4fe;
  border-color: #46d4fe;
}

#oceanwp-social-menu .minimal ul li.oceanwp-facebook a:hover {
  color: #37589b;
  border-color: #37589b;
}

#oceanwp-social-menu .minimal ul li.oceanwp-googleplus a:hover {
  color: #de5a49;
  border-color: #de5a49;
}

#oceanwp-social-menu .minimal ul li.oceanwp-pinterest a:hover {
  color: #cb2027;
  border-color: #cb2027;
}

#oceanwp-social-menu .minimal ul li.oceanwp-dribbble a:hover {
  color: #ea4c89;
  border-color: #ea4c89;
}

#oceanwp-social-menu .minimal ul li.oceanwp-vk a:hover {
  color: #597BA5;
  border-color: #597BA5;
}

#oceanwp-social-menu .minimal ul li.oceanwp-instagram a:hover {
  color: #3F729B;
  border-color: #3F729B;
}

#oceanwp-social-menu .minimal ul li.oceanwp-linkedin a:hover {
  color: #3399CC;
  border-color: #3399CC;
}

#oceanwp-social-menu .minimal ul li.oceanwp-tumblr a:hover {
  color: #2C4762;
  border-color: #2C4762;
}

#oceanwp-social-menu .minimal ul li.oceanwp-github a:hover {
  color: #60b044;
  border-color: #60b044;
}

#oceanwp-social-menu .minimal ul li.oceanwp-flickr a:hover {
  color: #fa4086;
  border-color: #fa4086;
}

#oceanwp-social-menu .minimal ul li.oceanwp-skype a:hover {
  color: #00AFF0;
  border-color: #00AFF0;
}

#oceanwp-social-menu .minimal ul li.oceanwp-youtube a:hover {
  color: #C4302B;
  border-color: #C4302B;
}

#oceanwp-social-menu .minimal ul li.oceanwp-vimeo a:hover {
  color: #1ab7ea;
  border-color: #1ab7ea;
}

#oceanwp-social-menu .minimal ul li.oceanwp-vine a:hover {
  color: #00bf8f;
  border-color: #00bf8f;
}

#oceanwp-social-menu .minimal ul li.oceanwp-xing a:hover {
  color: #006464;
  border-color: #006464;
}

#oceanwp-social-menu .minimal ul li.oceanwp-yelp a:hover {
  color: #C41200;
  border-color: #C41200;
}

#oceanwp-social-menu .minimal ul li.oceanwp-tripadvisor a:hover {
  color: #589442;
  border-color: #589442;
}

#oceanwp-social-menu .minimal ul li.oceanwp-rss a:hover {
  color: #ff7900;
  border-color: #ff7900;
}

#oceanwp-social-menu .minimal ul li.oceanwp-email a:hover {
  color: #13aff0;
  border-color: #13aff0;
}

#oceanwp-social-menu .dark ul li {
  padding: 0 2px;
}

#oceanwp-social-menu .dark ul li a {
  position: relative;
  display: inline-block;
  font-size: 12px;
  background-color: #333;
  color: #fff;
  line-height: 1;
  padding: 1em;
  border-radius: 50%;
  vertical-align: middle;
  -webkit-transition: all .3s ease-out;
  -moz-transition: all .3s ease-out;
  -o-transition: all .3s ease-out;
  transition: all .3s ease-out;
}

#oceanwp-social-menu .dark ul li a:hover {
  background-color: #000;
  color: #fff;
}

#oceanwp-social-menu .dark ul li a span {
  width: 1em;
  height: 1em;
}